emit

Function emit 

pub fn emit(
    scenario: &LoweredScenario,
    feature_stem: &str,
    world: &World,
) -> Option<Artifact>
Emit one scenario’s artifact set. None when the scenario lowers to no hurl entries (nothing to hand to the engine or the backend team).